#! /usr/bin/python
#
# This is a translator so that I2C devices can be connected to the serial bus
# It uses the BV4221_V2 to do the translation.
# NOTE the documentation for python SMBus is poor and so only the functions that
#      have checked agianst them are known to work   
#
# BEFORE USING
# The BV4221 needs to be attached to a console first and the following commands
# are required for use with this software
# Make sure that the BV4221_V2 has firmware version 2.5
# if not upgrade see http://doc.byvac.com/index.php5?title=Product_BV4221
# P0    // tuns off the prompt
# D     // sets decimal
# F     // fixes this behaviour
# B115200 // fixes baud rate
#
# Example of use:
# When using smbus:
# from smbus import SMBus
# bus = SMBus(0) # set to i2c channel
#
# When using byi2c:
# from by2c import By2cbus
# bus = By2cbus("COM3",115200) # specify com port and baud rate
#
# Both are used in the same way so code is intergchangable e.g.
# bus.read_byte_data(0x2f,0x58)
#
import serial
from time import sleep
#

class   By2cbus:
    """Common entry point for I2C, emulates subset of smbus"""
    """As an example
       import smbus
       bus = smbus.SMBus(0)
       OR
       inport bvbus
       bus = bvbus.bvbus(port,baud)
    """
    sp = None   # sp is set to communication device by Init()
    ACK = "*"
    def __init__(self,port,baud):
        try:
            self.sp=serial.Serial(port, baud, timeout=.05, stopbits=1, parity='N' )
            sleep(1)  # first output after connext is ACK  
        except:
            print "Can't open com port"
        
    # --------------------------------------------------------------------------
    # This is the only function needed for reading and writing to BV4221. It is
    # similar to spi in that there is always an input and output even if one
    # or the other is not required.
    # Use:
    # The cmd must be the full command including the address and \r at the end
    # Example: s = sv3(sp,"s 1 1 p\r") # 
    # Returns: Nothing as there is no error NAK for this device
    # --------------------------------------------------------------------------
    def bvi2c(self,cmd):
        k = ''
        v = ''
        # send command
        self.sp.flushInput()
        self.sp.write(cmd)
        #print "send ",cmd # debug
        # return value
        while k != self.ACK:
            k = self.sp.read(1)
            if k == self.ACK: # all done
                if len(v) == 0:
                    v = self.ACK
                break
            else:
                if len(k) == 0:
                    break
                else:
                    v = v + k
        return v

    # --------------------------------------------------------------------------
    # returns a list of devices
    # --------------------------------------------------------------------------
    def i2cdetect(self):
        s = self.bvi2c("x\r")
        ss = s.rsplit(',')
        rv = ''
        for j in ss:
            rv = str(int(j)/2)
        return rv
    # --------------------------------------------------------------------------
    # emulate smbus (send_byte)
    # s-a*2 p
    # --------------------------------------------------------------------------
    def write_quick(self,adr):
        adr *= 2 # need 8 bit address
        self.bvi2c("s-"+str(adr)+" p\r")

    # --------------------------------------------------------------------------
    # emulate smbus (receive_byte)
    # s-(a*2)+1 g-1 p
    # --------------------------------------------------------------------------
    def read_quick(self,adr):
        adr *= 2 # need 8 bit address
        adr += 1
        s = self.bvi2c("s-"+str(adr)+" g-1 p\r")
        v = 0
        try:
            v = int(s)
            return v
        except:
            return 0

    # --------------------------------------------------------------------------
    # emulate smbus (send_byte)
    # Checked okay
    # s-a*2 b p
    # --------------------------------------------------------------------------
    def write_byte(self,adr,b):
        adr *= 2 # need 8 bit address
        self.bvi2c("s-"+str(adr)+" "+str(b)+" p\r")

    # --------------------------------------------------------------------------
    # emulate smbus (receive_byte)
    # s-(a*2)+1 cmd g-1 p
    # --------------------------------------------------------------------------
    def read_byte_data(self,adr,cmd):
        adr *= 2 # need 8 bit address
        s = self.bvi2c("s-"+str(adr)+" "+str(cmd)+" r g-1 p\r")
        v = 0
        try:
            v = int(s)
            return v
        except:
            return 0

    # --------------------------------------------------------------------------
    # emulate smbus write_byte
    # s-a*2 cmd dat p
    # --------------------------------------------------------------------------
    def write_byte_data(self,adr,cmd,dat):
        adr *= 2 # need 8 bit address
        self.bvi2c("s-"+str(adr)+" "+str(cmd)+" "+str(dat)+" p\r")

    # --------------------------------------------------------------------------
    # read word
    # s-a*2 g-2 p
    # --------------------------------------------------------------------------
    def read_word(self,adr):
        adr *= 2 # need 8 bit address
        s = self.bvi2c("s-"+str(adr+1)+" g-2 p\r")
        v = 0
        try:
            ss = s.rsplit(",")
            v = int(ss[0])
            v += int(ss[1])*256
            return v
        except:
            return 0        

    # --------------------------------------------------------------------------
    # emulate smbus (read_word)
    # Checked expects low byte first
    # s-(a*2) cmd r g-2 p
    # --------------------------------------------------------------------------
    def read_word_data(self,adr,cmd):
        adr *= 2 # need 8 bit address
        s = self.bvi2c("s-"+str(adr)+" "+str(cmd)+" r g-2 p\r")
        v = 0
        try:
            ss = s.rsplit(",")
            v = int(ss[0])
            v += int(ss[1])*256
            return v
        except:
            return 0

    # --------------------------------------------------------------------------
    # emulate smbus (write_word)
    # Checked low byte is sent first
    # s-a*2 cmd dat p
    # --------------------------------------------------------------------------
    def write_word_data(self,adr,cmd,wrd):
        adr *= 2 # need 8 bit address
        h = wrd / 256
        l = wrd % 256
        self.bvi2c("s-"+str(adr)+" "+str(cmd)+" "+str(l)+" "+str(h)+" p\r")

    # --------------------------------------------------------------------------
    # emulate smbus
    # s-a*2 cmdWrdH cmdWrdL r g-2 p
    # --------------------------------------------------------------------------
    def process_call(self,adr,cmdWrd,wrd):
        adr *= 2 # need 8 bit address
        h = cmdWrd / 256
        l = cmdWrd % 256
        s = self.bvi2c("s-"+str(adr)+" "+str(h)+" "+str(l)+" r g-2 p\r")
        v = 0
        try:
            ss = rsplit(",")
            v = int(ss[0])*256
            v += int(ss[1])
            return v
        except:
            return 0

    # --------------------------------------------------------------------------
    # emulate smbus
    # s-(a*2) cmd r g-n p
    # cant be done without specifying number of bytes to read
    # --------------------------------------------------------------------------
    #def read_block_data(self,adr,cmd):

    # --------------------------------------------------------------------------
    # emulate smbus
    # checked Okay
    # s-(a*2)+1 g-1 p
    # --------------------------------------------------------------------------
    def read_byte(self,adr):
        adr *= 2 # need 8 bit address
        adr += 1
        s = self.bvi2c("s-"+str(adr)+" g-1 p\r")
        try:
            v = int(s)
            return v
        except:
            return 0

    # **************************************************************************
    # I2C access

    # --------------------------------------------------------------------------
    # emulate smbus ** as in Pyhton doc:
    # http://wiki.erazor-zone.de/wiki:linux:python:smbus:doc
    # s-a*2 cmd ..list.. p
    # --------------------------------------------------------------------------
    def write_i2c_block_data(self,adr,cmd,list):
        adr *= 2 # need 8 bit address
        cmdS =  "s-"+str(adr)+" "+str(cmd)+" "
        for n in list:
            cmdS = cmdS + str(n)+" "
        #print cmdS
        self.bvi2c(cmdS+" p\r")

    # --------------------------------------------------------------------------
    # i2c access using ambus ** must specify number of bytes to read
    # s-(a*2) cmd r g-1 p
    # --------------------------------------------------------------------------
    def read_i2c_block_data(self,adr,cmd,n):
        adr *= 2 # need 8 bit address
        s = self.bvi2c("s-"+str(adr)+" "+str(b)+" r g-"+n+" p\r")
        v = []
        try:
            for n in s:
                v.append(int(n))
            return v
        except:
            return 0

