#!/usr/bin/env python
# P011

from sv3common import sv3, util_error, util_information
from time import sleep

# Global
EEsettings = [] # saves changes for writing to ee[rpm
VoltRef = {1:'1.024V',2:'2.048V',3:'4.096V',4:'VDD'}

ACK = '\006'
NACK = '\025'

# ------------------------------------------------------------------------------
# start up and close down
# Load frame with default values, from EEPROM
# ------------------------------------------------------------------------------
def onActivate(wnd):
    global EEsettings
    wnd.lblDevice.SetLabel('Device ('+wnd.adr+')')
    # update status bar
    wnd.barStatus.SetStatusText(str(wnd.sp.port),1)
    wnd.barStatus.SetStatusText(str(wnd.sp.baudrate),2)
    s = sv3(wnd.sp,wnd.adr+"D\r") # device ID
    wnd.barStatus.SetStatusText(s,3)
    s =sv3(wnd.sp,wnd.adr+"V\r") # version
    wnd.barStatus.SetStatusText(s,4)
    wnd.barStatus.SetStatusText(wnd.adr,5)
    
    s = sv3(wnd.sp, wnd.adr+"R16,9\r")
    EEsettings = s.rsplit(",")
    
    # 16(L) & 17(H) is scale factor
    v = int(EEsettings[1])*256
    v += int(EEsettings[0])
    wnd.txtScale.SetValue(str(v))
    # 18 is Vref
    wnd.spnVolt.SetValue(int(EEsettings[2]))
    onVolt(wnd) # update lable
    # 19 is ADC Scan rate in mS
    wnd.txtAdcscan.SetValue(EEsettings[3])

# Close is important as this is a modal frame
def onClose(wnd,event):
    wnd.MakeModal(False)
    event.Skip()
    
# ******************************************************************************
# ******************************************************************************
# EVENTS

# ------------------------------------------------------------------------------
def onSoftreset(wnd):
    sv3(wnd.sp,wnd.adr+"C\r")
    wnd.barStatus.SetStatusText("Reset complete")

# ------------------------------------------------------------------------------
def onHardreset(wnd):
    wnd.sp.SetDTR(True)
    sleep(0.1)
    wnd.sp.SetDTR(False)
    wnd.barStatus.SetStatusText("Reset complete")

# ******************************************************************************
# 
# ******************************************************************************
# ------------------------------------------------------------------------------
# Scale button adjusts timer scale value
def onScale(wnd):
    v = int(wnd.txtScale.GetValue())
    # needs to be split into high and low bytes
    EEsettings[1] = str(v / 256) # high
    EEsettings[0] = str(v % 256) # low
    sv3(wnd.sp,wnd.adr+"W16,"+EEsettings[0]+"\r") # write value to eeprom
    sleep(0.1)
    sv3(wnd.sp,wnd.adr+"W17,"+EEsettings[1]+"\r") # write value to eeprom
    
# ------------------------------------------------------------------------------
# relay set on/off and time for A
def onSeta(wnd):
    t = wnd.txtDelaya.GetValue()
    if wnd.rdoA.GetSelection() == 0:
        sv3(wnd.sp,wnd.adr+"a1,"+t+"\r")
    else:
        sv3(wnd.sp,wnd.adr+"a0,"+t+"\r")

# ------------------------------------------------------------------------------
# relay set on/off and time for B
def onSetb(wnd):
    t = wnd.txtDelayb.GetValue()
    if wnd.rdoB.GetSelection() == 0:
        sv3(wnd.sp,wnd.adr+"b1,"+t+"\r")
    else:
        sv3(wnd.sp,wnd.adr+"b0,"+t+"\r")

# ------------------------------------------------------------------------------
# Helper updates all text boxes
def UpdateTextBoxes(wnd):
        v = sv3(wnd.sp,wnd.adr+"g1\r")
        wnd.txtAN1.SetValue(v)
        v = sv3(wnd.sp,wnd.adr+"g2\r")
        wnd.txtAN2.SetValue(v)
        v = sv3(wnd.sp,wnd.adr+"g3\r")
        wnd.txtAN3.SetValue(v)
        v = sv3(wnd.sp,wnd.adr+"g4\r")
        wnd.txtAN4.SetValue(v)
        
# ------------------------------------------------------------------------------
# Updates text boxes
def onUpdate(wnd):
        UpdateTextBoxes(wnd)

# ------------------------------------------------------------------------------
# Sets scan rate for adc
def onAdcscan(wnd):
    v = int(wnd.txtAdcscan.GetValue())
    if v > 255:
        v = 255
    if v < 0:
        v = 0
    if v == 0:
        util_information("0 will set the dealy to 256 mS")
    EEsettings[3] = str(v)
    sv3(wnd.sp,wnd.adr+"W19,"+EEsettings[3]+"\r") # write value to eeprom
    
# ------------------------------------------------------------------------------
# Digital channel 1
def onD1(wnd):
    if wnd.rdoD1.GetSelection() == 0:
        sv3(wnd.sp,wnd.adr+"d0\r")
    else:
        sv3(wnd.sp,wnd.adr+"d1\r")


# ------------------------------------------------------------------------------
# spinner update
def onVolt(wnd):
    # update lable
    vr = wnd.spnVolt.GetValue()
    wnd.lblVoltage.SetLabel(VoltRef[vr])
    # update device
    sv3(wnd.sp,wnd.adr+"v"+str(vr)+"\r")

# ------------------------------------------------------------------------------
# Scan rate buttond
def onScan(wnd):
    EEsettings[0] = wnd.txtScan.GetValue() # get new rate
    sv3(wnd.sp,wnd.adr+"W16,"+EEsettings[0]+"\r") # write to EEPROM
    onSoftreset(wnd)
    

"""
class bv4601(wx.Frame):
    def __init__(self, type, wnd, com, *args, **kwds):
        # begin wxGlade: pi11.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)

        if type == 'I':
            import bv4601_Ievents as events
        if type == 'S':
            import bv4601_events as events
        self.evt = events
        self.sp = com
        self.wnd = wnd
        self.adr = wnd.barStatus.GetStatusText(5)

        # Menu Bar

##binds
        self.Bind(wx.EVT_ACTIVATE, evt.onActivate(self))
        self.Bind(wx.EVT_CLOSE, self.onClose)

## events
    def onClose(self, event):  # wxGlade: bv4603.<event_handler>
        evt.onClose(self,event)

    def onSoftreset(self, event):  # wxGlade: bv4603.<event_handler>
        evt.onSoftreset(self)

    def onHardreset(self, event):  # wxGlade: bv4603.<event_handler>
        evt.onHardreset(self)

    def onScale(self, event):  # wxGlade: bv4601.<event_handler>
        evt.onScale(self)

    def onSeta(self, event):  # wxGlade: bv4601.<event_handler>
        evt.onSeta(self)

    def onSetb(self, event):  # wxGlade: bv4601.<event_handler>
        evt.onSetb(self)

    def onUpdate(self, event):  # wxGlade: bv4601.<event_handler>
        evt.onUpdate(self)

    def onVolt(self, event):  # wxGlade: bv4601.<event_handler>
        evt.onVolt(self)

    def onD1(self, event):  # wxGlade: bv4601.<event_handler>
        evt.onD1(self)

    def onAdcscan(self, event):  # wxGlade: bv4601.<event_handler>
        evt.onAdcscan(self)

"""
