#!/usr/bin/env python
# BV4614

from sv3common import sv3, util_error, util_information
from time import sleep
import datetime

# Global
EEsettings = [] # saves changes for writing to ee[rpm

ACK = '\006'
NACK = '\025'

# ------------------------------------------------------------------------------
# start up and close down
# Load frame with default values, from EEPROM
# ------------------------------------------------------------------------------
def onActivate(wnd):
    global EEsettings
    wnd.lblDevice.SetLabel('Device ('+wnd.adr+')')
    # update status bar
    wnd.barStatus.SetStatusText(str(wnd.sp.port),1)
    wnd.barStatus.SetStatusText(str(wnd.sp.baudrate),2)
    s = sv3(wnd.sp,wnd.adr+"D\r") # device ID
    wnd.barStatus.SetStatusText(s,3)
    s =sv3(wnd.sp,wnd.adr+"V\r") # version
    wnd.barStatus.SetStatusText(s,4)
    wnd.barStatus.SetStatusText(wnd.adr,5)
    
    # get eeprom values
    s = sv3(wnd.sp, wnd.adr+"R16,9\r")
    EEsettings = s.rsplit(",")

    # update brightness spinners
    wnd.spnGlobal.SetValue(int(EEsettings[0]))
    wnd.spnD1.SetValue(int(EEsettings[0]))
    wnd.spnD2.SetValue(int(EEsettings[1]))
    wnd.spnD3.SetValue(int(EEsettings[2]))
    wnd.spnD4.SetValue(int(EEsettings[3]))

# Close is important as this is a modal frame
def onClose(wnd,event):
    wnd.MakeModal(False)
    event.Skip()
    
# ******************************************************************************
# ******************************************************************************
# EVENTS

# ------------------------------------------------------------------------------
def onSoftreset(wnd):
    sv3(wnd.sp,wnd.adr+"C\r")
    wnd.barStatus.SetStatusText("Reset complete")

# ------------------------------------------------------------------------------
def onHardreset(wnd):
    wnd.sp.SetDTR(True)
    sleep(0.1)
    wnd.sp.SetDTR(False)
    wnd.barStatus.SetStatusText("Reset complete")

# ******************************************************************************
# Display
# ******************************************************************************

def onBlank(wnd):
    sv3(wnd.sp,wnd.adr+"c\r")

def onNumber(wnd):
    number = wnd.txtNumber.GetLineText(0)
    n = 0
    dp = 0 # dp has to go in after number
    for s in number:
        if s == '.':
            dp = 1
        else:
            sv3(wnd.sp,wnd.adr+"n"+str(n)+","+s+"\r")
            if dp == 1:
                dp = 0
                sv3(wnd.sp,wnd.adr+"p"+str(n-1)+",1\r")
            n =n + 1
        if n > 3:
            break

# brighteness spinners
def onGlobal(wnd):
    n = wnd.spnGlobal.GetValue()
    sv3(wnd.sp,wnd.adr+"b"+str(n)+"\r")
    wnd.spnD1.SetValue(n)
    wnd.spnD2.SetValue(n)
    wnd.spnD3.SetValue(n)
    wnd.spnD4.SetValue(n)

def onD1(wnd):  
    n = wnd.spnD1.GetValue()
    sv3(wnd.sp,wnd.adr+"i0,"+str(n)+"\r")
  
def onD2(wnd):  
    n = wnd.spnD2.GetValue()
    sv3(wnd.sp,wnd.adr+"i1,"+str(n)+"\r")

def onD3(wnd):  
    n = wnd.spnD3.GetValue()
    sv3(wnd.sp,wnd.adr+"i2,"+str(n)+"\r")

def onD4(wnd):  
    n = wnd.spnD4.GetValue()
    sv3(wnd.sp,wnd.adr+"i3,"+str(n)+"\r")
    
def onTime(wnd):
    now = datetime.datetime.now()
    wnd.txtNumber.SetValue(str(now.hour)+"."+str(now.minute))
    onNumber(wnd)

# Fix buttons
def onFixdisplay(wnd):
    sv3(wnd.sp,wnd.adr+"m\r")
    
def onFixbrightness(wnd):
    sv3(wnd.sp,wnd.adr+"e\r")
    
"""
class bv4614(wx.Frame):
    def __init__(self, wnd, com, *args, **kwds):
        # begin wxGlade: bv4614.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)

        self.sp = com
        self.wnd = wnd
        self.adr = wnd.barStatus.GetStatusText(5)

        # Menu Bar

##binds
        self.Bind(wx.EVT_ACTIVATE, evt.onActivate(self))
        self.Bind(wx.EVT_CLOSE, self.onClose)

## events
    def onClose(self, event):  # wxGlade: bv4603.<event_handler>
        evt.onClose(self,event)

    def onSoftreset(self, event):  # wxGlade: bv4603.<event_handler>
        evt.onSoftreset(self)

    def onHardreset(self, event):  # wxGlade: bv4603.<event_handler>
        evt.onHardreset(self)

    def onBlank(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onBlank(self)

    def onNumber(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onNumber(self)

    def onGlobal(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onGlobal(self)

    def onD1(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onD1(self)

    def onD2(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onD2(self)

    def onD3(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onD3(self)

    def onD4(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onD4(self)

    def onTime(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onTime(self)

    def onFixdisplay(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onFixdisplay(self)

    def onFixbrightness(self, event):  # wxGlade: bv4614.<event_handler>
        evt.onFixbrightness(self)

"""
