#!/usr/bin/env python
# P011

from sv3common import sv3, util_error, util_information
from time import sleep

# Global
EEsettings = [] # saves changes for writing to ee[rpm

ACK = '\006'
NACK = '\025'

# ------------------------------------------------------------------------------
# start up and close down
# Load frame with default values, from EEPROM
# ------------------------------------------------------------------------------
def onActivate(wnd):
    global EEsettings
    wnd.lblDevice.SetLabel('Device ('+wnd.adr+')')
    # update status bar
    wnd.barStatus.SetStatusText(str(wnd.sp.port),1)
    wnd.barStatus.SetStatusText(str(wnd.sp.baudrate),2)
    s = sv3(wnd.sp,wnd.adr+"D\r") # device ID
    wnd.barStatus.SetStatusText(s,3)
    s =sv3(wnd.sp,wnd.adr+"V\r") # version
    wnd.barStatus.SetStatusText(s,4)
    wnd.barStatus.SetStatusText(wnd.adr,5)
    
    s = sv3(wnd.sp, wnd.adr+"R16,9\r")
    EEsettings = s.rsplit(",")
    
    # 16,17,18 default back light values
    wnd.sldBL1.SetValue(int(EEsettings[0]))
    wnd.sldBL2.SetValue(int(EEsettings[1]))
    wnd.sldBL3.SetValue(int(EEsettings[2]))

# Close is important as this is a modal frame
def onClose(wnd,event):
    wnd.MakeModal(False)
    event.Skip()
    
# ******************************************************************************
# ******************************************************************************
# EVENTS

# ------------------------------------------------------------------------------
def onSoftreset(wnd):
    sv3(wnd.sp,wnd.adr+"C\r")
    wnd.barStatus.SetStatusText("Reset complete")

# ------------------------------------------------------------------------------
def onHardreset(wnd):
    wnd.sp.SetDTR(True)
    sleep(0.1)
    wnd.sp.SetDTR(False)
    wnd.barStatus.SetStatusText("Reset complete")

# ------------------------------------------------------------------------------
# sends commaand 1 to clear screen 
def onCls(wnd):    
    sv3(wnd.sp,wnd.adr+"c1\r") 
    
# ------------------------------------------------------------------------------
# send button sends what ever is on lines to display. This works by sending
# a command and value first to get the cursor to the start of the line
# the values work for most displays being:
# Line1 0x80
# Line2 0xco
# Line3 0x94
# Line4 0xd4
def onSend(wnd):
    # Line 1    
    l = wnd.txtLine1.GetLineText(0)
    if len(l) !=0:
        sv3(wnd.sp,wnd.adr+"c128\r") # start of line 1
        sv3(wnd.sp,wnd.adr+"d"+l+"\r") # contents of line
    # Line 2    
    l = wnd.txtLine2.GetLineText(0)
    if len(l) !=0:
        sv3(wnd.sp,wnd.adr+"c192\r") # start of line 2
        sv3(wnd.sp,wnd.adr+"d"+l+"\r") # contents of line
    # Line 3
    l = wnd.txtLine3.GetLineText(0)
    if len(l) !=0:
        sv3(wnd.sp,wnd.adr+"c148\r") # start of line 3
        sv3(wnd.sp,wnd.adr+"d"+l+"\r") # contents of line
    # Line 4    
    l = wnd.txtLine4.GetLineText(0)
    if len(l) !=0:
        sv3(wnd.sp,wnd.adr+"c212\r") # start of line 4
        sv3(wnd.sp,wnd.adr+"d"+l+"\r") # contents of line

# ------------------------------------------------------------------------------
# sliders alter the value for the rgb PWM signals, monochrome backlights 
# just use BL1 (red) 
# The default values are in EEsettings 
def onBL1(wnd):    
    EEsettings[0] = str(wnd.sldBL1.GetValue())
    sv3(wnd.sp,wnd.adr+"b"+EEsettings[0]+","+EEsettings[1]+","+EEsettings[2]+"\r")

def onBL2(wnd):    
    EEsettings[1] = str(wnd.sldBL2.GetValue())
    sv3(wnd.sp,wnd.adr+"b"+EEsettings[0]+","+EEsettings[1]+","+EEsettings[2]+"\r")

def onBL3(wnd):    
    EEsettings[2] = str(wnd.sldBL3.GetValue())
    sv3(wnd.sp,wnd.adr+"b"+EEsettings[0]+","+EEsettings[1]+","+EEsettings[2]+"\r")

# ------------------------------------------------------------------------------
# Alters eeprom contents to reflect text lines and also BL settings. To send
# a command preceed it by a 1 and finidh off with 0
def onSignon(wnd):
    ee = 32
    # Line 1    
    l = wnd.txtLine1.GetLineText(0)
    if len(l) !=0:
        sv3(wnd.sp,wnd.adr+"W"+str(ee)+",1\r") # command follows
        ee += 1
        sleep(0.1)
        sv3(wnd.sp,wnd.adr+"W"+str(ee)+",128\r") # start of line 1
        for n in l:
            ee += 1
            sleep(0.1)
            sv3(wnd.sp,wnd.adr+"W"+str(ee)+","+str(ord(n))+"\r") # contents of line
    
    # Line 2    
    l = wnd.txtLine2.GetLineText(0)
    if len(l) !=0:
        ee += 1
        sv3(wnd.sp,wnd.adr+"W"+str(ee)+",1\r") # command follows
        ee += 1
        sleep(0.1)
        sv3(wnd.sp,wnd.adr+"W"+str(ee)+",192\r") # start of line 2
        for n in l:
            ee += 1
            sleep(0.1)
            sv3(wnd.sp,wnd.adr+"W"+str(ee)+","+str(ord(n))+"\r") # contents of line

    # Line 3    
    l = wnd.txtLine3.GetLineText(0)
    if len(l) !=0:
        ee += 1
        sv3(wnd.sp,wnd.adr+"W"+str(ee)+",1\r") # command follows
        ee += 1
        sleep(0.1)
        sv3(wnd.sp,wnd.adr+"W"+str(ee)+",148\r") # start of line 3
        for n in l:
            ee += 1
            sleep(0.1)
            sv3(wnd.sp,wnd.adr+"W"+str(ee)+","+str(ord(n))+"\r") # contents of line

    # Line 4    
    l = wnd.txtLine4.GetLineText(0)
    if len(l) !=0:
        ee += 1
        sv3(wnd.sp,wnd.adr+"W"+str(ee)+",1\r") # command follows
        ee += 1
        sleep(0.1)
        sv3(wnd.sp,wnd.adr+"W"+str(ee)+",212\r") # start of line 4
        for n in l:
            ee += 1
            sleep(0.1)
            sv3(wnd.sp,wnd.adr+"W"+str(ee)+","+str(ord(n))+"\r") # contents of line

    ee += 1
    sv3(wnd.sp,wnd.adr+"W"+str(ee)+",0\r") # finish
    
    # now Back light settings
    sv3(wnd.sp,wnd.adr+"W16,"+EEsettings[0]+"\r")
    sv3(wnd.sp,wnd.adr+"W17,"+EEsettings[1]+"\r")
    sv3(wnd.sp,wnd.adr+"W18,"+EEsettings[2]+"\r")

    wnd.barStatus.SetStatusText("EEPROM Updated",0)
    
# ******************************************************************************
# 
# ******************************************************************************

"""
class p017(wx.Frame):
    def __init__(self, wnd, com, *args, **kwds):
        # begin wxGlade: pi11.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)

        self.sp = com
        self.wnd = wnd
        self.adr = wnd.barStatus.GetStatusText(5)

        # Menu Bar

##binds
        self.Bind(wx.EVT_ACTIVATE, evt.onActivate(self))
        self.Bind(wx.EVT_CLOSE, self.onClose)

## events
    def onClose(self, event):  # wxGlade: bv4603.<event_handler>
        evt.onClose(self,event)

    def onSoftreset(self, event):  # wxGlade: bv4603.<event_handler>
        evt.onSoftreset(self)

    def onHardreset(self, event):  # wxGlade: bv4603.<event_handler>
        evt.onHardreset(self)

    def onSend(self, event):  # wxGlade: p017.<event_handler>
        evt.onSend(self)

    def onCls(self, event):  # wxGlade: p017.<event_handler>
        evt.onCls(self)

    def onBL1(self, event):  # wxGlade: p017.<event_handler>
        evt.onBL1(self)

    def onBL2(self, event):  # wxGlade: p017.<event_handler>
        evt.onBL2(self)

    def onBL3(self, event):  # wxGlade: p017.<event_handler>
        evt.onBL3(self)

    def onSignon(self,event):  # wxGlade: p017.<event_handler>
        evt.onSignon(self)

"""
