#!/usr/bin/env python

import serial
import wx

ACK = '\006'
NACK = '\025'


# ==============================================================================
# Part 1 utilities
# ==============================================================================

def util_error(msg):
    dlg = wx.MessageDialog(None, msg, "Error", wx.OK | wx.ICON_ERROR)
    dlg.ShowModal()
    dlg.Destroy()

def util_information(msg):
    dlg = wx.MessageDialog(None, msg, "Information", wx.OK | wx.ICON_INFORMATION)
    dlg.ShowModal()
    dlg.Destroy()

def Connect(sp,port,baud):
    if sp: # already connected so disconnect
        sp.close()
        sp = None
    try:
        sp = serial.Serial(port, baud, timeout=.05, stopbits=1, parity='N' )
    except:
        sp = None
    return sp

def writeIni(sp,adr):
    opf = open('sv3.ini','w')
    #print sp.name,sp.baudrate
    if opf:
        opf.write(sp.name+',')
        opf.write(str(sp.baudrate)+',')
        opf.write(adr)
        opf.close()

# ------------------------------------------------------------------------------
# This is the only function needed for reading and writingto SV3. It is
# similar to spi in that there is always an input and output even if one
# or the other is not required.
# Use:
# The cmd must be the full command including the address and \r at the end
# Example: s = sv3(sp,"aD\r") # get device ID from device with an address 'a'
# Returns:
# 1) NACK on an invalid input or if device does not exist
# 2) The value returned or just ACK
# ------------------------------------------------------------------------------
def sv3(com,cmd):
    k = ''
    v = ''
    # send command
    com.flushInput()
    com.write(cmd)
    #print "sending:",cmd # debug
    # return value
    while k != ACK:
        k = com.read(1)
        if k == ACK: # all done
            if len(v) == 0:
                v = ACK
            break
        else:
            if len(k) == 0:
                v = NACK
                break
            else:
                v = v + k
    return v

# ==============================================================================
# Part 2 I2C utilities
# ==============================================================================

# ------------------------------------------------------------------------------
# Writes command and two bytes using smbus word method, write a,b where a is 
# first byte and b is second
# ------------------------------------------------------------------------------
def i2c_twobytes(bus,adr,cmd,a,b):
    wrd = (b*256)+a
    bus.write_word_data(adr,cmd,wrd)

